@@ -72,7 +72,7 @@ impl FromRequest for Subscription {
             let vapid: Option<VapidHeaderWithKey> = parse_vapid(&token_info, &app_state.metrics)?
                 .map(|vapid| extract_public_key(vapid, &token_info))
                 .transpose()?;
-            trace!("raw vapid: {:?}", &vapid);
+            trace!("🔍 raw vapid: {:?}", &vapid);
             // Validate the VAPID JWT token, fetch the claims, and record the version
             if let Some(with_key) = &vapid {
                 // Validate the VAPID JWT token and record the version
@@ -349,7 +349,7 @@ fn validate_vapid_jwt(
                 return Err(VapidError::InvalidAudience.into());
             }
             jsonwebtoken::errors::ErrorKind::MissingRequiredClaim(e) => {
-                return Err(VapidError::InvalidVapid(format!("Missing required {}", e)).into());
+                return Err(VapidError::InvalidVapid(format!("Missing required {e}")).into());
             }
             _ => {
                 // Attempt to match up the majority of ErrorKind variants.
@@ -565,13 +565,6 @@ pub mod tests {
 
     #[test]
     fn vapid_public_key_variants() {
-        #[derive(Debug, Deserialize, Serialize)]
-        struct StrExpVapidClaims {
-            exp: String,
-            aud: String,
-            sub: String,
-        }
-
         // pretty much matches the kind of key we get from some partners.
         let public_key_standard = "BM3bVjW/wuZC54alIbqjTbaBNtthriVtdZlchOyOSdbVYeYQu2i5inJdft7jUWIAy4O9xHBbY196Gf+1odb8hds=".to_owned();
         let public_key_url_safe = "BM3bVjW_wuZC54alIbqjTbaBNtthriVtdZlchOyOSdbVYeYQu2i5inJdft7jUWIAy4O9xHBbY196Gf-1odb8hds=".to_owned();
