@@ -1,6 +1,9 @@
+// Rust 1.89.0 flags `StorageType` as unused even with `bigtable` set as a default feature.
+#[allow(dead_code)]
 #[derive(Clone, Eq, PartialEq, Debug)]
 pub(crate) enum StorageType {
     BigTable,
+    Redis,
     None,
 }
 
@@ -8,6 +11,8 @@ impl Default for StorageType {
     fn default() -> StorageType {
         if cfg!(feature = "bigtable") {
             StorageType::BigTable
+        } else if cfg!(feature = "redis") {
+            StorageType::Redis
         } else {
             StorageType::None
         }
@@ -18,6 +23,7 @@ impl From<&str> for StorageType {
     fn from(str: &str) -> StorageType {
         match str.to_lowercase().as_str() {
             "bigtable" => StorageType::BigTable,
+            "redis" => StorageType::Redis,
             _ => {
                 warn!("Using default StorageType for {str}");
                 StorageType::default()
